==> noahs-2.1.1.tar.gz: noahs/src/Plugin/Control/ControlTextarea.php <==
<?php 

namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;

/**
 * @ControlPlugin(
 *   id = "textarea",
 *   label = @Translation("Textarea")
 * )
 */

class ControlTextarea extends ControlBase{
	
	public function get_type() {
		return 'textarea';
	}

	public function content_template(array $params = []) {

		$data = $params['data'] ?? null;
    	$name = $params['name'] ?? null;
    	$value = $params['value'] ?? null;
    	$delta = $params['delta'] ?? null;
		$text_editor = !empty($data['item']['format']) && $data['item']['format'] === 'noahs_textarea_plain' ? $data['item']['format'] : 'noahs_textarea_full_html';
		$value = isset($value) ? $value : $data['item']['default_value'];
		$placeholder = !empty($data['item']['placeholder']) ? $data['item']['placeholder']  : '';
		$selector = !empty($data['item']['update_selector']) ? 'data-update-selector="#widget-id-' .$data['wid'] .'"' : null;
		if(!empty($delta)){
			$selector = !empty($data['item']['update_selector']) ? 'data-update-selector="#widget-id-' .$data['wid'] . ' ' .str_replace('[index]', $delta, $data['item']['update_selector']).'"' : null;
		}

		// if(isset($data['delta'])){
		// 	if (strpos($selector, '[index]') !== false) {
		// 		$selector = str_replace('[index]', $data['delta'], $selector);
		// 	} 
		// }
		$output = '<div class="field field__textarea">';
		$output .= '<textarea 
					name="' . $name .'" 
					id="noahs_page_builder_textarea_' . $data['item_id'] . '" 
					title="' . $data['item']['title'] .'"
					'.$text_editor.'
					field-settings
					placeholder="'. $placeholder .'" 
					rows="10" 
					cols="50"
					class="noahs_page_builder_textarea" '.$selector.'>
					'.$value.'
					</textarea>';
		$output .= '</div>';
		return $output;
	}
	public function render_control($data){
		return $this->base($data, $this->content_template($data));
	}
	public function get_default_settings() {
		return [
			'input_type' => 'text',
			'placeholder' => '',
			'title' => '',
		];
	}
}

==> noahs-2.1.2.tar.gz: noahs/src/Plugin/Control/ControlTextarea.php <==
<?php 

namespace Drupal\noahs_page_builder\Plugin\Control;

use Drupal\noahs_page_builder\Annotation\ControlPlugin;
use Drupal\noahs_page_builder\Plugin\Control\ControlBase;

/**
 * @ControlPlugin(
 *   id = "textarea",
 *   label = @Translation("Textarea")
 * )
 */

class ControlTextarea extends ControlBase{
	
	public function get_type() {
		return 'textarea';
	}

	public function content_template(array $params = []) {

		$data = $params['data'] ?? null;
		$name = $params['name'] ?? null;
		$value = $params['value'] ?? null;
		$delta = $params['delta'] ?? null;
		$text_editor = !empty($data['item']['format']) && $data['item']['format'] === 'noahs_textarea_plain' ? $data['item']['format'] : 'noahs_textarea_full_html';
		$value = isset($value) ? $value : $data['item']['default_value'];
		$placeholder = !empty($data['item']['placeholder']) ? $data['item']['placeholder']  : '';
		$selector = !empty($data['item']['update_selector']) ? 'data-update-selector="#widget-id-' .$data['wid'] . ' ' .$data['item']['update_selector'].'"' : null;

		if(!empty($delta)){
			$selector = !empty($data['item']['update_selector']) ? 'data-update-selector="#widget-id-' .$data['wid'] . ' ' .str_replace('[index]', $delta, $data['item']['update_selector']).'"' : null;
		}

		// if(isset($data['delta'])){
		// 	if (strpos($selector, '[index]') !== false) {
		// 		$selector = str_replace('[index]', $data['delta'], $selector);
		// 	} 
		// }
		$output = '<div class="field field__textarea">';
		$output .= '<textarea 
					name="' . $name .'" 
					id="noahs_page_builder_textarea_' . $data['item_id'] . '" 
					title="' . $data['item']['title'] .'"
					'.$text_editor.'
					field-settings
					placeholder="'. $placeholder .'" 
					rows="10" 
					cols="50"
					class="noahs_page_builder_textarea" '.$selector.'>'.$value.'</textarea>';
		$output .= '</div>';
		return $output;
	}
	public function render_control($data){
		return $this->base($data, $this->content_template($data));
	}
	public function get_default_settings() {
		return [
			'input_type' => 'text',
			'placeholder' => '',
			'title' => '',
		];
	}
}
